@@ -1,7 +1,7 @@
 import json
 from collections import defaultdict
 from pathlib import Path
-from typing import Set, Dict, Any
+from typing import Set, Dict, Any, List
 
 from leap_model_parser.contract.importmodelresponse import NodeResponse, WrapperData
 
@@ -41,14 +41,49 @@ class KerasJsonModelImport:
         _add_origin_name_to_nodes(nodes)
         return nodes
 
+    '''
+    Convert tf ops inbound nodes to the same format as the regular layers.
+    examples:
+    1.
+        ['conv2d_2', 0, 0, {'slice_spec': [{'start': None, 'stop': None, 'step': None}]}
+        will be converted to:
+        [['conv2d_2', 0, 0]]
+    2.
+        ['tf.__operators__.getitem_1', 0, 0, {'y': ['tf.__operators__.getitem_1', 0, 0]}]
+        will be converted to:
+        [['tf.__operators__.getitem_1', 0, 0], ['tf.__operators__.getitem_1', 0, 0]]
+    '''
+    @staticmethod
+    def prepare_inbound_nodes_of_tf_ops(inbound_nodes_to_enumerate: List):
+        inbound_nodes_to_enumerate_prepared = []
+        single_inbound_node_to_enumerate = []
+        for element in inbound_nodes_to_enumerate:
+            if type(element) in (int, str):
+                single_inbound_node_to_enumerate.append(element)
+            elif isinstance(element, dict):
+                if single_inbound_node_to_enumerate and type(single_inbound_node_to_enumerate[0]) == str:
+                    inbound_nodes_to_enumerate_prepared.append(single_inbound_node_to_enumerate)
+                single_inbound_node_to_enumerate = []
+                for inbound_nodes in element.values():
+                    if isinstance(inbound_nodes, list):
+                        inbound_nodes_to_enumerate_prepared.extend(
+                            KerasJsonModelImport.prepare_inbound_nodes_of_tf_ops(inbound_nodes))
+        if single_inbound_node_to_enumerate and type(single_inbound_node_to_enumerate[0]) == str:
+            inbound_nodes_to_enumerate_prepared.append(single_inbound_node_to_enumerate)
+
+        return inbound_nodes_to_enumerate_prepared
+
     def generate_graph_recursive(self, current_layer: Dict[str, Any], instance_index: int):
         self.generate_node(current_layer, instance_index)
 
         inbound_nodes = current_layer['inbound_nodes']
         if len(inbound_nodes) == 0:
             return
+        inbound_nodes_to_enumerate = inbound_nodes[instance_index]
+        if not isinstance(inbound_nodes_to_enumerate[0], list):
+            inbound_nodes_to_enumerate = self.prepare_inbound_nodes_of_tf_ops(inbound_nodes_to_enumerate)
 
-        for input_index, input_layer_item in enumerate(inbound_nodes[instance_index]):
+        for input_index, input_layer_item in enumerate(inbound_nodes_to_enumerate):
             input_layer = self.layer_name_to_layer[input_layer_item[0]]
             self.generate_node(input_layer, input_layer_item[1])
 
@@ -114,6 +149,9 @@ class KerasJsonModelImport:
 
     def generate_regular_node(self, layer: Dict[str, Any], layer_metadata: Dict[str, Any], node_key: str):
         data = layer['config']
+        if layer['class_name'] in ('TFOpLambda', 'SlicingOpLambda'):
+            data['inbound_nodes'] = layer['inbound_nodes'][0]
+
         self.layer_data_adjustments(data, layer_metadata)
         node = NodeResponse(id=str(self.id), name=layer["class_name"], data=data)
         if 'wrapper' in layer:
